package model;

import java.io.File;
import java.util.LinkedList;

@SuppressWarnings("serial")
public class ToDoList extends LinkedList<ToDo> implements Operable {
	private File file;
	private boolean changed;
	public ToDoList() {
		super();
		changed = false;
		file = null;
	}
	public boolean hasChanged() {
		return changed;
	}
	public void setChanged() {
		changed = true;
	}
	public boolean saveAs(File f) {
		file = f;
		String fileName = f.getAbsolutePath();
		int dotPos = fileName.lastIndexOf('.');
		String extension = fileName.substring(dotPos + 1);
		FileType ft = FileType.typeForExtension(extension);
		Saver recorder = new Saver(this);
		boolean saved = recorder.saveAs(fileName, ft);
		if (saved) changed = false;
		return saved;
	}
	public boolean save() {
		return saveAs(file);
	}
	public boolean load(File f) {
		file = f;
		Loader loader = new Loader(this);
		boolean loaded = loader.loadFrom(f);
		if (!loaded) return false;
		changed = false;
		return true;
	}
    public String fileName() {
        String name = (changed) ? "*" : "";
        if (file == null) name += "Sans nom";
        else name += file.getName();
        return name; 
    }
	public void sort() {
		sort((ToDo t1, ToDo t2) -> t1.compareTo(t2));
	}
	public void performs(Operation op) throws Exception {
		op.doItOn(this);
	}
}
